<?php

namespace Drupal\commerce_webform_order;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\webform\WebformSubmissionInterface;

/**
 * Helps for loading and listing webform submission's order items.
 */
class OrderItemRepository implements OrderItemRepositoryInterface {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a new OrderItemRepository.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public function getAllByWebformSubmission(WebformSubmissionInterface $webform_submission) {
    /** @var \Drupal\commerce_order\Entity\OrderItemInterface[] $order_items */
    $order_item_storage = $this->entityTypeManager->getStorage('commerce_order_item');
    if (!empty($order_items = $order_item_storage->loadByProperties(['commerce_webform_order_submission', $webform_submission->id()]))) {
      return $order_items;
    }

    return NULL;
  }

  /**
   * {@inheritdoc}
   */
  public function getLastByWebformSubmission(WebformSubmissionInterface $webform_submission) {
    /** @var \Drupal\commerce_order\Entity\OrderItemInterface[] $order_items */
    $order_item_storage = $this->entityTypeManager->getStorage('commerce_order_item');
    $order_item_ids = $order_item_storage
      ->getQuery()
      ->condition('commerce_webform_order_submission', $webform_submission->id())
      ->sort('order_item_id', 'DESC')
      ->accessCheck(FALSE)
      ->range(0, 1)
      ->execute();

    if (!empty($order_item_ids) && !empty($order_items = $order_item_storage->loadMultiple($order_item_ids))) {
      return reset($order_items);
    }

    return NULL;
  }

}
